@@ -37,7 +37,17 @@ class PaymentMethod(Resource):
                     "overwrite_brand",
                     "selected_brand"
                 ]
-            }
+            },
+            {
+                "paypal": [
+                    "payee_email",
+                    "order_id",
+                    "custom_field",
+                    "description",
+                    "amount",
+                    { "shipping": Address.create_signature() }
+                ],
+            },
         ]
 
         signature = [
@@ -52,6 +62,8 @@ class PaymentMethod(Resource):
             "expiration_year",
             "number",
             "payment_method_nonce",
+            "paypal_refresh_token",
+            "paypal_vault_without_upgrade",
             "token",
             {
                 "billing_address": Address.create_signature()
